pub enum ToDeviceEncryptedEventContent {
OlmV1Curve25519AesSha2(Box<OlmV1Curve25519AesSha2Content>),
Unknown(UnknownEncryptedContent),
}Expand description
The content for m.room.encrypted to-device events.
Variants
OlmV1Curve25519AesSha2(Box<OlmV1Curve25519AesSha2Content>)
The event content for events encrypted with the m.megolm.v1.aes-sha2 algorithm.
Unknown(UnknownEncryptedContent)
An event content that was encrypted with an unknown encryption algorithm.
Implementations
Sourceimpl ToDeviceEncryptedEventContent
impl ToDeviceEncryptedEventContent
Sourcepub fn algorithm(&self) -> EventEncryptionAlgorithm
pub fn algorithm(&self) -> EventEncryptionAlgorithm
Get the algorithm of the event content.