pub struct MegolmV1AesSha2Content {
pub ciphertext: MegolmMessage,
pub sender_key: Option<Curve25519PublicKey>,
pub device_id: Option<OwnedDeviceId>,
pub session_id: String,
}Expand description
The event content for events encrypted with the m.megolm.v1.aes-sha2 algorithm.
Fields
ciphertext: MegolmMessageThe encrypted content of the event.
sender_key: Option<Curve25519PublicKey>The Curve25519 key of the sender.
device_id: Option<OwnedDeviceId>The ID of the sending device.
session_id: StringThe ID of the session used to encrypt the message.