pub enum RoomEventEncryptionScheme {
MegolmV1AesSha2(MegolmV1AesSha2Content),
Unknown(UnknownEncryptedContent),
}Expand description
An enum for per encryption algorithm event contents.
Variants
MegolmV1AesSha2(MegolmV1AesSha2Content)
The event content for events encrypted with the m.megolm.v1.aes-sha2 algorithm.
Unknown(UnknownEncryptedContent)
An event content that was encrypted with an unknown encryption algorithm.
Implementations
Sourceimpl RoomEventEncryptionScheme
impl RoomEventEncryptionScheme
Sourcepub fn algorithm(&self) -> EventEncryptionAlgorithm
pub fn algorithm(&self) -> EventEncryptionAlgorithm
Get the algorithm of the event content.